@@ -1,4 +1,4 @@
-#include <baseapi.h>
+#include <tesseract/baseapi.h>
 #include <allheaders.h>
 
 #define R_NO_REMAP
